widgetTitle property
A custom title for the updates popup, or null when unset (callers then
fall back to their own default).
Implementation
final String? widgetTitle;
A custom title for the updates popup, or null when unset (callers then
fall back to their own default).
final String? widgetTitle;